# __Author__ = "Pranav Chandran"
# __Date__ = 08-03-2023
# __Time__ = 11:29
# __FileName__ = __init__.py

from .console_gpt import ChatbotGPT
